@@ -16,6 +16,8 @@ describe 'ovn::controller' do
       :ovn_openflow_probe_interval => 8,
       :ovn_transport_zones         => ['tz1'],
       :enable_ovn_match_northd     => false,
+      :ovn_chassis_mac_map         => ['physnet1:aa:bb:cc:dd:ee:ff',
+                                       'physnet2:bb:aa:cc:dd:ee:ff']
     }
   end
 
@@ -82,7 +84,9 @@ describe 'ovn::controller' do
       is_expected.to contain_vs_config('external_ids:ovn-match-northd-version').with(
         :value   => params[:enable_ovn_match_northd],
       )
-
+      is_expected.to contain_vs_config('external_ids:ovn-chassis-mac-mappings').with(
+        :value    => 'physnet1:aa:bb:cc:dd:ee:ff,physnet2:bb:aa:cc:dd:ee:ff',
+      )
     end
 
     it 'configures bridge mappings' do
@@ -100,6 +104,22 @@ describe 'ovn::controller' do
         :require => 'Service[openvswitch]'
       )
     end
+
+    context 'when ovn_chassis_mac_map is a hash' do
+      before :each do
+        params.merge!({
+          :ovn_chassis_mac_map => {
+            'physnet1' => 'aa:bb:cc:dd:ee:ff',
+            'physnet2' => 'bb:aa:cc:dd:ee:ff' }
+        })
+      end
+
+      it 'configures ovsdb' do
+        is_expected.to contain_vs_config('external_ids:ovn-chassis-mac-mappings').with(
+          :value    => 'physnet1:aa:bb:cc:dd:ee:ff,physnet2:bb:aa:cc:dd:ee:ff',
+        )
+      end
+    end
   end
 
   on_supported_os({
